@@ -186,7 +186,7 @@ class Factory(object):
         if field.name in attrs:
             return True, attrs.pop(field.name)
         else:
-            if model in not_including:
+            if field.related.parent_model in not_including:
                 return False, None
             has_factory, value = self._get_value_from_model_factory(model, field)
             if not has_factory:
@@ -216,7 +216,7 @@ class Factory(object):
         if field.name in attrs:
             return True, attrs.pop(field.name)
         else:
-            if model in not_including:
+            if field.related.parent_model in not_including:
                 return False, None
             has_factory, value = self._get_value_from_model_factory(model, field)
             if not has_factory:
@@ -541,7 +541,7 @@ class Factory(object):
             type of ``field``.
         """
         if getattr(field, 'choices'):
-            generator = lambda x, y: get_from_choices(field.choices)
+            generator = lambda x, y: get_from_choices(field.flatchoices)
         else:
             generator = self.field_mapping.get(field.__class__)
         if generator is None:
