@@ -49,6 +49,12 @@ class TestGenerators(TestCase):
         generated = generators.generate_unicode(self.field, self.factory)
         self.assertThat(generated, StartsWith(self.field.name))
 
+    def test_generate_unicode_respects_max_length(self):
+        field = test_models.ModelWithMaxLengthCharField._meta.get_field(
+                'char_field')
+        generated = generators.generate_unicode(field, self.factory)
+        self.assertEquals(field.max_length, len(generated))
+
     def test_generate_int_generates_int(self):
         generated = generators.generate_int(self.field, self.factory)
         self.assertIsInstance(generated, int)
@@ -539,6 +545,16 @@ class FactoryGenerateValueTests(DjangoTestCase, TestCase):
         self.assertEqual(test_models.ModelWithChoices.CHOICES[0][0],
                 value)
 
+    def test_chooses_from_choices_with_groups(self):
+        # Still selects the first choice, even if there are choice
+        # groups.
+        factory = Factory()
+        model = test_models.ModelWithChoiceGroups
+        field = self.get_field(model, 'choices_field')
+        value = factory.generate_value(field)
+        self.assertEqual(test_models.ModelWithChoiceGroups.CHOICES[0][1][0][0],
+                value)
+
     def test_type_error_on_unknown_field(self):
         factory = Factory()
         class Field(django_fields.Field):
@@ -773,8 +789,7 @@ class TestFactory(DjangoTestCase, TestCase):
         factory = Factory()
         instance = factory.make_one(test_models.ModelWithCircularReferenceLoop1)
         self.assertEqual(1, instance.things.count())
-        self.assertEqual(1, instance.things.get().other_things.count())
-        self.assertEqual(0, instance.things.get().other_things.get().things.count())
+        self.assertEqual(0, instance.things.get().other_things.count())
 
     def test_make_one_breaks_many_to_many_self_reference_loop(self):
         # If a model referenes itself in a ManyToManyField the loop will
@@ -865,6 +880,22 @@ class TestFactory(DjangoTestCase, TestCase):
         self.assertIsInstance(instance.thing.thing,
                 test_models.ModelReferencedByForiegnKeyField)
 
+    def test_make_one_makes_fk_for_every_self_needed_for_m2m(self):
+        # Where a model with a self m2m field has a foriegn key,
+        # instances are created for that foreign key for every
+        # self instance created
+        factory = Factory()
+        instance = factory.make_one(test_models.ModelWithForeignKeyAndSelfManyToMany)
+        self.assertIsInstance(instance,
+                test_models.ModelWithForeignKeyAndSelfManyToMany)
+        self.assertIsInstance(instance.thing,
+                test_models.ModelReferencedByForiegnKeyField)
+        self.assertEqual(1, instance.selves.count())
+        self.assertIsInstance(instance.selves.get(),
+                test_models.ModelWithForeignKeyAndSelfManyToMany)
+        self.assertIsInstance(instance.selves.get().thing,
+                test_models.ModelReferencedByForiegnKeyField)
+
     def test_make_one_passes_attrs_to_instance_generator(self):
         # Any factory instance generator gets passed the attrs passed to
         # make_one so that it can used them when generating the
